==> order-center-api-2.9.0-CLOUD-20220819.123154-6-sources.jar: com/tydic/dyc/oc/service/cmporder/bo/UocGetCmpOrderDetailServiceRspMaterialBo.java <==
package com.tydic.dyc.oc.service.cmporder.bo;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题：类名称:UocGetCmpOrderDetailServiceReqItemBo
 * 说明：描述一下类的作用TODO
 * 时间：2022/3/29 14:06
 * 作者 @author 尹栋梁
 */
@Data
public class UocGetCmpOrderDetailServiceRspMaterialBo implements Serializable {
    private static final long serialVersionUID = -4744603246705319672L;

    private Long id;

    @DocField(value = "比选单id")
    private Long cmpOrderId;

    @DocField(value = "商品名称	")
    private String skuName;

    @DocField(value = "物料id")
    private String skuMaterialId;

    @DocField(value = "物料描述")
    private String skuMaterialDesc;

    @DocField(value = "购买数量")
    private String purchaseCount;

    @DocField(value = "单品排序")
    private Integer skuOrder;

    @DocField(value = "创建时间")
    private Date createTime;

    @DocField(value = "创建时间 开始")
    private Date createTimeStart;

    @DocField(value = "创建时间 结束")
    private Date createTimeEnd;

    @DocField(value = "创建工号")
    private String createOperId;

    @DocField(value = "更新时间")
    private Date updateTime;

    @DocField(value = "更新时间 开始")
    private Date updateTimeStart;

    @DocField(value = "更新时间 结束")
    private Date updateTimeEnd;

    @DocField(value = "更新工号")
    private String updateOperId;

    @DocField(value = "备注")
    private String remark;

    @DocField(value = "删除标志1已删除")
    private Integer delTag;

    @DocField(value = "排序")
    private String orderBy;
}

==> order-center-api-3.0.0-CLOUD-20251113.071832-90-sources.jar: com/tydic/dyc/oc/service/cmporder/bo/UocGetCmpOrderDetailServiceRspMaterialBo.java <==
package com.tydic.dyc.oc.service.cmporder.bo;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题：类名称:UocGetCmpOrderDetailServiceReqItemBo
 * 说明：描述一下类的作用TODO
 * 时间：2022/3/29 14:06
 * 作者 @author 尹栋梁
 */
@Data
public class UocGetCmpOrderDetailServiceRspMaterialBo implements Serializable {
    private static final long serialVersionUID = -4744603246705319672L;

    private Long id;

    /**
     * 比选单id
     */
    private Long cmpOrderId;

    /**
     * 商品名称
     */
    private String skuName;

    /**
     * 物料id
     */
    private String skuMaterialId;

    /**
     * 物料描述
     */
    private String skuMaterialDesc;

    /**
     * 购买数量
     */
    private String purchaseCount;

    /**
     * 单品排序
     */
    private Integer skuOrder;

    /**
     * 创建时间
     */
    private Date createTime;

    /**
     * 创建时间 开始
     */
    private Date createTimeStart;

    /**
     * 创建时间 结束
     */
    private Date createTimeEnd;

    /**
     * 创建工号
     */
    private String createOperId;

    /**
     * 更新时间
     */
    private Date updateTime;

    /**
     * 更新时间 开始
     */
    private Date updateTimeStart;

    /**
     * 更新时间 结束
     */
    private Date updateTimeEnd;

    /**
     * 更新工号
     */
    private String updateOperId;

    /**
     * 备注
     */
    private String remark;

    /**
     * 删除标志1已删除
     */
    private Integer delTag;

    /**
     * 排序
     */
    private String orderBy;

    /**
     * 租户id
     */
    private Long sysTenantId;
    private String sysTenantName;
}
